# ---------------------------------------------------------------------------
# createHeatMap.py
# Created on: 2011-05-17 14:34:17.00000
# Description: 
# ---------------------------------------------------------------------------

import os, sys, arcpy

# change to geodatabse
myWorkspace                 = arcpy.GetParameterAsText(0)
arcpy.env.workspace         = myWorkspace
arcpy.env.overwriteOutput   = True

# register spatial analyst extension for point to raster conversion
arcpy.CheckOutExtension("Spatial")

# define input and output feature names
inFeature                   = arcpy.GetParameterAsText(1)
fns = {}
fns['building_type']        = arcpy.GetParameterAsText(2)
fns['nr_of_floors']         = arcpy.GetParameterAsText(3)
fns['year_of_construction'] = arcpy.GetParameterAsText(4)
fns['measured_consumption'] = arcpy.GetParameterAsText(5)

polyFeature   = os.path.basename(inFeature) + "_Polygon"
pointFeature  = os.path.basename(inFeature) + "_Point"
rasterFeature = os.path.basename(inFeature) + "_Raster"
tableFeature  = os.path.basename(inFeature) + "_Table"
fieldName = "Heat_Demand"

codeBlock = open(sys.path[0]+os.sep+'fHeatDemand.py', 'r').read()
functionCall = "fHeatDemand("+\
                   "'!"+fns['building_type']+"!',"+\
                   "!ShapeArea!,"+\
                   "'!"+fns['nr_of_floors']+"!',"+\
                   "'!"+fns['year_of_construction']+"!',"+\
                   "'!"+fns['measured_consumption']+"!'"+\
               ")"


# copy building shapes to new temporary layer
arcpy.SetProgressor("step", "Copying feature... (1/6)", 0, 100, 17)
arcpy.CopyFeatures_management(inFeature, polyFeature)
arcpy.SetProgressorPosition()

# calculate centroid coordinates and shape area
arcpy.SetProgressorLabel("Calculating shape areas and center points... (2/6)")
arcpy.AddField_management(polyFeature, "CentroidX", "DOUBLE")
arcpy.AddField_management(polyFeature, "CentroidY", "DOUBLE")
arcpy.AddField_management(polyFeature, "ShapeArea", "DOUBLE")
arcpy.CalculateField_management(polyFeature, "CentroidX", "float(!SHAPE.CENTROID!.replace(',','.').split()[0])", "PYTHON")
arcpy.CalculateField_management(polyFeature, "CentroidY", "float(!SHAPE.CENTROID!.replace(',','.').split()[1])", "PYTHON")
arcpy.CalculateField_management(polyFeature, "ShapeArea", "float(!SHAPE.AREA@SQUAREMETERS!)", "PYTHON")
arcpy.SetProgressorPosition()

# calculate heat demand
arcpy.SetProgressorLabel("Calculating heat demand per building... (3/6)")
arcpy.AddField_management(polyFeature, fieldName, "DOUBLE")
arcpy.CalculateField_management(polyFeature, fieldName, functionCall, "PYTHON", codeBlock)
arcpy.SetProgressorPosition()

# convert polygon feature to table
arcpy.SetProgressorLabel("Convert to table... (4/6)")
arcpy.TableToTable_conversion(polyFeature, myWorkspace, tableFeature)
arcpy.SetProgressorPosition()

# convert table to point layer 
arcpy.SetProgressorLabel("Convert to points... (5/6)")
arcpy.MakeXYEventLayer_management(tableFeature, "CentroidX", "CentroidY", pointFeature)
arcpy.SetProgressorPosition()

# aggregate points to raster
arcpy.SetProgressorLabel("Aggregate to raster map... (6/6)")
arcpy.PointToRaster_conversion(pointFeature, fieldName, rasterFeature, "SUM", "", 200)
arcpy.SetProgressorPosition()

arcpy.ResetProgressor()