import arcpy, os, sys, csv
BuildingTypeMapping={}
csvReader = csv.reader(open(sys.path[0]+os.sep+'..'+os.sep+'ToolData'+os.sep+'BuildingTypeMapping.csv','r'), delimiter=';')
for row in csvReader:
    BuildingTypeMapping[row[0].strip()] = row[1].strip()

heat_demand = {
    'residential_small':{0:150, 1969:130, 1984:115, 1996:100, 2002: 90},
    'residential_big':  {0:125, 1969:110, 1984: 95, 1996: 80, 2002: 50},
    'office':           {0:130, 1952:140, 1978:100, 1996: 70},
    'trade_small':       140,
    'trade_big':          85,
    'industry_small':     35,
    'industry_big':       50,
    'other':              55,
    'zero':                0 
}

def fHeatDemand(building_type, building_area, nr_of_floors = 1, year_of_construction = 0, measured_consumption = 0):
    # calculates heat demand of building (kWh/a)
    try:
        if float(measured_consumption) > 0:
            return measured_consumption
        else:
            pass
    except ValueError:
        pass

    try:
        if int(year_of_construction) >= 0:
            year_of_construction = int(year_of_construction)
        else:
            year_of_construction = 0
    except ValueError:
        year_of_construction = 0

    try:
        if int(nr_of_floors) > 0:
            nr_of_floors = int(nr_of_floors)
        else:
            nr_of_floors = 1
    except ValueError:
        nr_of_floors = 1

    # check building_area
    try:
        building_area = float(building_area)
    except ValueError:
        print "Error in fHeatDemand: Invalid value for building_area given..."
        raise
    
        
    # mapping of building types
    if building_type in BuildingTypeMapping.keys():
        building_type = BuildingTypeMapping[building_type]
    elif building_type in BuildingTypeMapping.values():
        pass
    else:
        building_type = 'other'


    # determine specific heat demand coefficient (kWh/m^2/a)
    if type(heat_demand[building_type]) == dict:
        # types with age-dependent statistics
        years = sorted(heat_demand[building_type].keys())
        if year_of_construction < years[0]:
            year_of_construction = years[0]
            
        for year in reversed(years):
            if year <= year_of_construction:
                specific_demand = heat_demand[building_type][year]
                break

    # remaining types
    elif building_type in heat_demand.keys():
        specific_demand = heat_demand[building_type]
    # unknown types
    else:
        specific_demand = heat_demand['other']

    # output specific_demand * gross_area
    return building_area*nr_of_floors*specific_demand
